==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>Kablosuz Aç</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>Kablosuz kapat</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation>Büyük Harf aç</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>Büyük Harf kapat</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>Sayısal Klavyeyi aç</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>Sayısal Klavye kapat</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>Dokunmatik Yüzey aç</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>Dokunmatik Yüzey kapat</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>Uçak Kipi  açık</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>Uçak Kipi kapalı</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>Dengeli Güç</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>Güç tasarrufu</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>Yüksek performans</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>Pencere etkisi etkinleştirildi</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>Pencere etkisi devre dışı bırakıldı</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>Pencere etkileri etkinleştirilemedi</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.1.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Kablosuz Aç</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Kablosuz kapat</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Büyük Harf aç</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Büyük Harf kapat</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Sayısal Klavyeyi aç</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Sayısal Klavye kapat</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Dokunmatik Yüzey aç</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Dokunmatik Yüzey kapat</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Dokunmatik yüzeyi açma</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn açma</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Uçak Kipi  açık</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Uçak Kipi kapalı</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Sessiz açık</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Sessiz kapalı</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Dengeli Güç</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Güç tasarrufu</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Yüksek performans</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Pencere etkisi etkinleştirildi</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Pencere etkisi devre dışı bırakıldı</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Pencere etkileri etkinleştirilemedi</translation>
    </message>
</context>
</TS>
